@@ -1,12 +1,12 @@
-#line 1 "inc/Module/Install/Build.pm - /usr/share/perl5/Module/Install/Build.pm"
-# $File: //depot/cpan/Module-Install/lib/Module/Install/Build.pm $ $Author: ingy $
-# $Revision: #23 $ $Change: 1255 $ $DateTime: 2003/03/05 13:23:32 $ vim: expandtab shiftwidth=4
-
+#line 1 "inc/Module/Install/Build.pm - /usr/local/lib/perl5/site_perl/5.8.7/Module/Install/Build.pm"
 package Module::Install::Build;
+
+use Module::Install::Base;
+@ISA = qw(Module::Install::Base);
+
 $VERSION = '0.01';
+
 use strict;
-use vars qw(@ISA);
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
 sub Build { $_[0] }
 
@@ -19,6 +19,7 @@ sub write {
 
     $args{dist_name} = $self->name || $self->determine_NAME($self->{args});
     $args{license} = $self->license;
+    $args{test_files} = $self->tests;
     $args{dist_version} = $self->version || $self->determine_VERSION($self->{args});
     $args{dist_abstract} = $self->abstract;
     $args{dist_author} = $self->author;
@@ -58,9 +59,8 @@ sub ACTION_dist {
 # <DrMath> ingy: then my $build = new MyBuilder( ...parameters... );
 #           $build->write_build_script;
 
-
 1;
 
 __END__
 
-#line 178
+#line 177
